py1090
======

This is a Python 3 module that allows handling of ADS-B messages in a pythonic way.
It can connect to a BaseStation TCP server, such as [dump1090](https://github.com/MalcolmRobb/dump1090) and parse its messages.

There is a version of the [full documentation at ReadTheDocs.org](http://py1090.readthedocs.org/), containing the API documentation, a description of the BaseStation format and examples.


